@@ -16,7 +16,7 @@ def get_video_info(
     download=False
     ):
     registryMgr = get_registryManager(video_directory=video_directory, envPath=envPath, info_directory=info_directory)
-    return registryMgr.get_video_info(url=url, video_id=video_id, force_refresh=force_refresh,download=download)
+    return registryMgr.get_video_info(url=url, video_id=video_id, force_refresh=force_refresh)
 def get_video_info_spec(
     key=None,
     url=None,
